PowerLetrics Dashboard

This dashboard only shows the last five minutes of data.

The idea of this dashboard is to give you a quick insight into the data and not for it to be run for a long period of time. The problem is that the longer we run the more data we collect and we collect a lot of data. And fairly soon we need a proper database. And for this project we want to focus on the Linux stuff and not on DBs.

Select Columns